#ifndef CREATURE_ADDON_H
#define CREATURE_ADDON_H

#include "Creature.h"
#include "Graphics.h"

enum {
	PLAYABLE = 0x00000001 // player can play this creature type
};

class Dungeon;

class CreatureInfo
{
	public:
		CreatureInfo();

		uint32 LoadGraphics( Graphics *, uint32 id ); // load bitmap and set id
		virtual Creature * Create( Dungeon * );
		virtual bool ShouldPlace( int level ); // level currently ignored
		
		const char		* name;
		uint32			flags;
		
	protected:
		bitmap_info		* bitmaps;
};

class CreatureBuilder
{
	public:
		CreatureBuilder( const char * );

		virtual Creature * Create( Dungeon *, const char * name = NULL );

		int NumCreatures();
		CreatureInfo * CreatureAt( int );
		
		uint32 LoadGraphics( Graphics *, uint32 );
		
		const char * text;
		
	protected:
		CreatureInfo ** info;
};

class CreatureInfoSet
{
	public:
		CreatureInfoSet();
		~CreatureInfoSet();
		
		void LoadAddons();
		void UnloadAddons();
		
		int NumCreatures();
		CreatureInfo * CreatureAt( int );
		CreatureInfo * FindCreature( const char * );
		uint32 LoadGraphics( Graphics *, uint32 );
		
	protected:
		List<CreatureInfo>		info_list;
		List<CreatureBuilder>	builder_list;
		List<image_id>			addon_list;
};

extern "C" __declspec(dllexport) CreatureBuilder * CreateBuilder();

#endif
