#ifndef OBJECT_ADDON_H
#define OBJECT_ADDON_H

#include "Object.h"
#include "Graphics.h"
#include "misc.h"

class Dungeon;

class ObjectInfo
{
	public:
		ObjectInfo();

		uint32 LoadGraphics( Graphics *, uint32 id ); // load bitmap and set id
		virtual Object * Create( Dungeon * );
		virtual bool ShouldPlace( int level ); // level currently ignored
				
		const char		* name;
		bitmap_info		* bitmaps;
		uint32			flags;

	protected:
		uint32	bitmap_id;
};

class ObjectBuilder
{
	public:
		ObjectBuilder( const char * );

		virtual Object * Create( Dungeon *, const char * name = NULL );

		int NumObjects();
		ObjectInfo * ObjectAt( int );

		uint32 LoadGraphics( Graphics *, uint32 );
		
		const char * text;

	protected:
		ObjectInfo ** info;
};

extern "C" __declspec(dllexport) ObjectBuilder * CreateObjectBuilder();

class ObjectInfoSet
{
	public:
		ObjectInfoSet();
		~ObjectInfoSet();
		
		void LoadAddons();
		void UnloadAddons();
		
		int NumObjects();
		ObjectInfo * ObjectAt( int );
		ObjectInfo * FindObject( const char * );
		uint32 LoadGraphics( Graphics *, uint32 );
		
	protected:
		List<ObjectInfo>		info_list;
		List<ObjectBuilder>		builder_list;
		List<image_id>			addon_list;
};

#endif
